# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/streams/v1/streams_v1.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from strmprivacy.api.entities.v1 import entities_v1_pb2 as strmprivacy_dot_api_dot_entities_dot_v1_dot_entities__v1__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+strmprivacy/api/streams/v1/streams_v1.proto\x12\x1astrmprivacy.api.streams.v1\x1a\x1fgoogle/api/field_behavior.proto\x1a-strmprivacy/api/entities/v1/entities_v1.proto\"S\n\x12ListStreamsRequest\x12\x16\n\nbilling_id\x18\x01 \x01(\tB\x02\x18\x01\x12\x11\n\trecursive\x18\x02 \x01(\x08\x12\x12\n\nproject_id\x18\x03 \x01(\t\"O\n\x13ListStreamsResponse\x12\x38\n\x07streams\x18\x01 \x03(\x0b\x32\'.strmprivacy.api.entities.v1.StreamTree\"0\n\x1aListExtendedStreamsRequest\x12\x12\n\nclient_ids\x18\x01 \x03(\t\"d\n\x1bListExtendedStreamsResponse\x12\x45\n\x10\x65xtended_streams\x18\x01 \x03(\x0b\x32+.strmprivacy.api.entities.v1.ExtendedStream\"g\n\x13\x44\x65leteStreamRequest\x12\x38\n\x03ref\x18\x01 \x01(\x0b\x32&.strmprivacy.api.entities.v1.StreamRefB\x03\xe0\x41\x02\x12\x16\n\trecursive\x18\x02 \x01(\x08\x42\x03\xe0\x41\x02\"\x16\n\x14\x44\x65leteStreamResponse\"O\n\x13\x43reateStreamRequest\x12\x38\n\x06stream\x18\x01 \x01(\x0b\x32#.strmprivacy.api.entities.v1.StreamB\x03\xe0\x41\x02\"K\n\x14\x43reateStreamResponse\x12\x33\n\x06stream\x18\x01 \x01(\x0b\x32#.strmprivacy.api.entities.v1.Stream\"d\n\x10GetStreamRequest\x12\x38\n\x03ref\x18\x01 \x01(\x0b\x32&.strmprivacy.api.entities.v1.StreamRefB\x03\xe0\x41\x02\x12\x16\n\trecursive\x18\x02 \x01(\x08\x42\x03\xe0\x41\x02\"Q\n\x11GetStreamResponse\x12<\n\x0bstream_tree\x18\x01 \x01(\x0b\x32\'.strmprivacy.api.entities.v1.StreamTree2\xd9\x04\n\x0eStreamsService\x12n\n\x0bListStreams\x12..strmprivacy.api.streams.v1.ListStreamsRequest\x1a/.strmprivacy.api.streams.v1.ListStreamsResponse\x12\x86\x01\n\x13ListExtendedStreams\x12\x36.strmprivacy.api.streams.v1.ListExtendedStreamsRequest\x1a\x37.strmprivacy.api.streams.v1.ListExtendedStreamsResponse\x12h\n\tGetStream\x12,.strmprivacy.api.streams.v1.GetStreamRequest\x1a-.strmprivacy.api.streams.v1.GetStreamResponse\x12q\n\x0c\x44\x65leteStream\x12/.strmprivacy.api.streams.v1.DeleteStreamRequest\x1a\x30.strmprivacy.api.streams.v1.DeleteStreamResponse\x12q\n\x0c\x43reateStream\x12/.strmprivacy.api.streams.v1.CreateStreamRequest\x1a\x30.strmprivacy.api.streams.v1.CreateStreamResponseBf\n\x1dio.strmprivacy.api.streams.v1P\x01ZCgithub.com/strmprivacy/api-definitions-go/v2/api/streams/v1;streamsb\x06proto3')



_LISTSTREAMSREQUEST = DESCRIPTOR.message_types_by_name['ListStreamsRequest']
_LISTSTREAMSRESPONSE = DESCRIPTOR.message_types_by_name['ListStreamsResponse']
_LISTEXTENDEDSTREAMSREQUEST = DESCRIPTOR.message_types_by_name['ListExtendedStreamsRequest']
_LISTEXTENDEDSTREAMSRESPONSE = DESCRIPTOR.message_types_by_name['ListExtendedStreamsResponse']
_DELETESTREAMREQUEST = DESCRIPTOR.message_types_by_name['DeleteStreamRequest']
_DELETESTREAMRESPONSE = DESCRIPTOR.message_types_by_name['DeleteStreamResponse']
_CREATESTREAMREQUEST = DESCRIPTOR.message_types_by_name['CreateStreamRequest']
_CREATESTREAMRESPONSE = DESCRIPTOR.message_types_by_name['CreateStreamResponse']
_GETSTREAMREQUEST = DESCRIPTOR.message_types_by_name['GetStreamRequest']
_GETSTREAMRESPONSE = DESCRIPTOR.message_types_by_name['GetStreamResponse']
ListStreamsRequest = _reflection.GeneratedProtocolMessageType('ListStreamsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTSTREAMSREQUEST,
  '__module__' : 'strmprivacy.api.streams.v1.streams_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.streams.v1.ListStreamsRequest)
  })
_sym_db.RegisterMessage(ListStreamsRequest)

ListStreamsResponse = _reflection.GeneratedProtocolMessageType('ListStreamsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTSTREAMSRESPONSE,
  '__module__' : 'strmprivacy.api.streams.v1.streams_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.streams.v1.ListStreamsResponse)
  })
_sym_db.RegisterMessage(ListStreamsResponse)

ListExtendedStreamsRequest = _reflection.GeneratedProtocolMessageType('ListExtendedStreamsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTEXTENDEDSTREAMSREQUEST,
  '__module__' : 'strmprivacy.api.streams.v1.streams_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.streams.v1.ListExtendedStreamsRequest)
  })
_sym_db.RegisterMessage(ListExtendedStreamsRequest)

ListExtendedStreamsResponse = _reflection.GeneratedProtocolMessageType('ListExtendedStreamsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTEXTENDEDSTREAMSRESPONSE,
  '__module__' : 'strmprivacy.api.streams.v1.streams_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.streams.v1.ListExtendedStreamsResponse)
  })
_sym_db.RegisterMessage(ListExtendedStreamsResponse)

DeleteStreamRequest = _reflection.GeneratedProtocolMessageType('DeleteStreamRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETESTREAMREQUEST,
  '__module__' : 'strmprivacy.api.streams.v1.streams_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.streams.v1.DeleteStreamRequest)
  })
_sym_db.RegisterMessage(DeleteStreamRequest)

DeleteStreamResponse = _reflection.GeneratedProtocolMessageType('DeleteStreamResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETESTREAMRESPONSE,
  '__module__' : 'strmprivacy.api.streams.v1.streams_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.streams.v1.DeleteStreamResponse)
  })
_sym_db.RegisterMessage(DeleteStreamResponse)

CreateStreamRequest = _reflection.GeneratedProtocolMessageType('CreateStreamRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATESTREAMREQUEST,
  '__module__' : 'strmprivacy.api.streams.v1.streams_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.streams.v1.CreateStreamRequest)
  })
_sym_db.RegisterMessage(CreateStreamRequest)

CreateStreamResponse = _reflection.GeneratedProtocolMessageType('CreateStreamResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATESTREAMRESPONSE,
  '__module__' : 'strmprivacy.api.streams.v1.streams_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.streams.v1.CreateStreamResponse)
  })
_sym_db.RegisterMessage(CreateStreamResponse)

GetStreamRequest = _reflection.GeneratedProtocolMessageType('GetStreamRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSTREAMREQUEST,
  '__module__' : 'strmprivacy.api.streams.v1.streams_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.streams.v1.GetStreamRequest)
  })
_sym_db.RegisterMessage(GetStreamRequest)

GetStreamResponse = _reflection.GeneratedProtocolMessageType('GetStreamResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETSTREAMRESPONSE,
  '__module__' : 'strmprivacy.api.streams.v1.streams_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.streams.v1.GetStreamResponse)
  })
_sym_db.RegisterMessage(GetStreamResponse)

_STREAMSSERVICE = DESCRIPTOR.services_by_name['StreamsService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\035io.strmprivacy.api.streams.v1P\001ZCgithub.com/strmprivacy/api-definitions-go/v2/api/streams/v1;streams'
  _LISTSTREAMSREQUEST.fields_by_name['billing_id']._options = None
  _LISTSTREAMSREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001'
  _DELETESTREAMREQUEST.fields_by_name['ref']._options = None
  _DELETESTREAMREQUEST.fields_by_name['ref']._serialized_options = b'\340A\002'
  _DELETESTREAMREQUEST.fields_by_name['recursive']._options = None
  _DELETESTREAMREQUEST.fields_by_name['recursive']._serialized_options = b'\340A\002'
  _CREATESTREAMREQUEST.fields_by_name['stream']._options = None
  _CREATESTREAMREQUEST.fields_by_name['stream']._serialized_options = b'\340A\002'
  _GETSTREAMREQUEST.fields_by_name['ref']._options = None
  _GETSTREAMREQUEST.fields_by_name['ref']._serialized_options = b'\340A\002'
  _GETSTREAMREQUEST.fields_by_name['recursive']._options = None
  _GETSTREAMREQUEST.fields_by_name['recursive']._serialized_options = b'\340A\002'
  _LISTSTREAMSREQUEST._serialized_start=155
  _LISTSTREAMSREQUEST._serialized_end=238
  _LISTSTREAMSRESPONSE._serialized_start=240
  _LISTSTREAMSRESPONSE._serialized_end=319
  _LISTEXTENDEDSTREAMSREQUEST._serialized_start=321
  _LISTEXTENDEDSTREAMSREQUEST._serialized_end=369
  _LISTEXTENDEDSTREAMSRESPONSE._serialized_start=371
  _LISTEXTENDEDSTREAMSRESPONSE._serialized_end=471
  _DELETESTREAMREQUEST._serialized_start=473
  _DELETESTREAMREQUEST._serialized_end=576
  _DELETESTREAMRESPONSE._serialized_start=578
  _DELETESTREAMRESPONSE._serialized_end=600
  _CREATESTREAMREQUEST._serialized_start=602
  _CREATESTREAMREQUEST._serialized_end=681
  _CREATESTREAMRESPONSE._serialized_start=683
  _CREATESTREAMRESPONSE._serialized_end=758
  _GETSTREAMREQUEST._serialized_start=760
  _GETSTREAMREQUEST._serialized_end=860
  _GETSTREAMRESPONSE._serialized_start=862
  _GETSTREAMRESPONSE._serialized_end=943
  _STREAMSSERVICE._serialized_start=946
  _STREAMSSERVICE._serialized_end=1547
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/cli/v1/cli.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n strmprivacy/api/cli/v1/cli.proto\x12\x16strmprivacy.api.cli.v1\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1fgoogle/protobuf/timestamp.proto\")\n\x11GetReleaseRequest\x12\x14\n\x07version\x18\x01 \x01(\tB\x03\xe0\x41\x01\"N\n\x12GetReleaseResponse\x12\x38\n\x07release\x18\x01 \x01(\x0b\x32\".strmprivacy.api.cli.v1.CliReleaseB\x03\xe0\x41\x03\"\x8e\x01\n\nCliRelease\x12\x14\n\x07version\x18\x01 \x01(\tB\x03\xe0\x41\x03\x12\x35\n\x0crelease_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03\x12\x17\n\nsource_uri\x18\x03 \x01(\tB\x03\xe0\x41\x03\x12\x1a\n\rrelease_notes\x18\x04 \x01(\tB\x03\xe0\x41\x03\x32q\n\nCliService\x12\x63\n\nGetRelease\x12).strmprivacy.api.cli.v1.GetReleaseRequest\x1a*.strmprivacy.api.cli.v1.GetReleaseResponseBZ\n\x19io.strmprivacy.api.cli.v1P\x01Z;github.com/strmprivacy/api-definitions-go/v2/api/cli/v1;clib\x06proto3')



_GETRELEASEREQUEST = DESCRIPTOR.message_types_by_name['GetReleaseRequest']
_GETRELEASERESPONSE = DESCRIPTOR.message_types_by_name['GetReleaseResponse']
_CLIRELEASE = DESCRIPTOR.message_types_by_name['CliRelease']
GetReleaseRequest = _reflection.GeneratedProtocolMessageType('GetReleaseRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETRELEASEREQUEST,
  '__module__' : 'strmprivacy.api.cli.v1.cli_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.cli.v1.GetReleaseRequest)
  })
_sym_db.RegisterMessage(GetReleaseRequest)

GetReleaseResponse = _reflection.GeneratedProtocolMessageType('GetReleaseResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETRELEASERESPONSE,
  '__module__' : 'strmprivacy.api.cli.v1.cli_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.cli.v1.GetReleaseResponse)
  })
_sym_db.RegisterMessage(GetReleaseResponse)

CliRelease = _reflection.GeneratedProtocolMessageType('CliRelease', (_message.Message,), {
  'DESCRIPTOR' : _CLIRELEASE,
  '__module__' : 'strmprivacy.api.cli.v1.cli_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.cli.v1.CliRelease)
  })
_sym_db.RegisterMessage(CliRelease)

_CLISERVICE = DESCRIPTOR.services_by_name['CliService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\031io.strmprivacy.api.cli.v1P\001Z;github.com/strmprivacy/api-definitions-go/v2/api/cli/v1;cli'
  _GETRELEASEREQUEST.fields_by_name['version']._options = None
  _GETRELEASEREQUEST.fields_by_name['version']._serialized_options = b'\340A\001'
  _GETRELEASERESPONSE.fields_by_name['release']._options = None
  _GETRELEASERESPONSE.fields_by_name['release']._serialized_options = b'\340A\003'
  _CLIRELEASE.fields_by_name['version']._options = None
  _CLIRELEASE.fields_by_name['version']._serialized_options = b'\340A\003'
  _CLIRELEASE.fields_by_name['release_time']._options = None
  _CLIRELEASE.fields_by_name['release_time']._serialized_options = b'\340A\003'
  _CLIRELEASE.fields_by_name['source_uri']._options = None
  _CLIRELEASE.fields_by_name['source_uri']._serialized_options = b'\340A\003'
  _CLIRELEASE.fields_by_name['release_notes']._options = None
  _CLIRELEASE.fields_by_name['release_notes']._serialized_options = b'\340A\003'
  _GETRELEASEREQUEST._serialized_start=126
  _GETRELEASEREQUEST._serialized_end=167
  _GETRELEASERESPONSE._serialized_start=169
  _GETRELEASERESPONSE._serialized_end=247
  _CLIRELEASE._serialized_start=250
  _CLIRELEASE._serialized_end=392
  _CLISERVICE._serialized_start=394
  _CLISERVICE._serialized_end=507
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/usage/v1/usage_v1.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from strmprivacy.api.entities.v1 import entities_v1_pb2 as strmprivacy_dot_api_dot_entities_dot_v1_dot_entities__v1__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'strmprivacy/api/usage/v1/usage_v1.proto\x12\x18strmprivacy.api.usage.v1\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a-strmprivacy/api/entities/v1/entities_v1.proto\"\xdc\x01\n\x1aGetStreamEventUsageRequest\x12\x33\n\x03ref\x18\x01 \x01(\x0b\x32&.strmprivacy.api.entities.v1.StreamRef\x12.\n\nstart_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x65nd_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12+\n\x08interval\x18\x04 \x01(\x0b\x32\x19.google.protobuf.Duration\"\x94\x01\n\x1bGetStreamEventUsageResponse\x12\x33\n\x03ref\x18\x01 \x01(\x0b\x32&.strmprivacy.api.entities.v1.StreamRef\x12@\n\x07windows\x18\x02 \x03(\x0b\x32/.strmprivacy.api.entities.v1.WindowedEventCount\"\xa1\x01\n\x16StoreUsageEventRequest\x12\x16\n\nbilling_id\x18\x01 \x01(\tB\x02\x18\x01\x12\x0e\n\x06stream\x18\x02 \x01(\t\x12\x13\n\x0b\x65vent_count\x18\x03 \x01(\x05\x12\x36\n\x12\x65vent_arrival_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\nproject_id\x18\x05 \x01(\t\"\x19\n\x17StoreUsageEventResponse2\x8b\x02\n\x0cUsageService\x12\x82\x01\n\x13GetStreamEventUsage\x12\x34.strmprivacy.api.usage.v1.GetStreamEventUsageRequest\x1a\x35.strmprivacy.api.usage.v1.GetStreamEventUsageResponse\x12v\n\x0fStoreUsageEvent\x12\x30.strmprivacy.api.usage.v1.StoreUsageEventRequest\x1a\x31.strmprivacy.api.usage.v1.StoreUsageEventResponseB`\n\x1bio.strmprivacy.api.usage.v1P\x01Z?github.com/strmprivacy/api-definitions-go/v2/api/usage/v1;usageb\x06proto3')



_GETSTREAMEVENTUSAGEREQUEST = DESCRIPTOR.message_types_by_name['GetStreamEventUsageRequest']
_GETSTREAMEVENTUSAGERESPONSE = DESCRIPTOR.message_types_by_name['GetStreamEventUsageResponse']
_STOREUSAGEEVENTREQUEST = DESCRIPTOR.message_types_by_name['StoreUsageEventRequest']
_STOREUSAGEEVENTRESPONSE = DESCRIPTOR.message_types_by_name['StoreUsageEventResponse']
GetStreamEventUsageRequest = _reflection.GeneratedProtocolMessageType('GetStreamEventUsageRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSTREAMEVENTUSAGEREQUEST,
  '__module__' : 'strmprivacy.api.usage.v1.usage_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.usage.v1.GetStreamEventUsageRequest)
  })
_sym_db.RegisterMessage(GetStreamEventUsageRequest)

GetStreamEventUsageResponse = _reflection.GeneratedProtocolMessageType('GetStreamEventUsageResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETSTREAMEVENTUSAGERESPONSE,
  '__module__' : 'strmprivacy.api.usage.v1.usage_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.usage.v1.GetStreamEventUsageResponse)
  })
_sym_db.RegisterMessage(GetStreamEventUsageResponse)

StoreUsageEventRequest = _reflection.GeneratedProtocolMessageType('StoreUsageEventRequest', (_message.Message,), {
  'DESCRIPTOR' : _STOREUSAGEEVENTREQUEST,
  '__module__' : 'strmprivacy.api.usage.v1.usage_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.usage.v1.StoreUsageEventRequest)
  })
_sym_db.RegisterMessage(StoreUsageEventRequest)

StoreUsageEventResponse = _reflection.GeneratedProtocolMessageType('StoreUsageEventResponse', (_message.Message,), {
  'DESCRIPTOR' : _STOREUSAGEEVENTRESPONSE,
  '__module__' : 'strmprivacy.api.usage.v1.usage_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.usage.v1.StoreUsageEventResponse)
  })
_sym_db.RegisterMessage(StoreUsageEventResponse)

_USAGESERVICE = DESCRIPTOR.services_by_name['UsageService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033io.strmprivacy.api.usage.v1P\001Z?github.com/strmprivacy/api-definitions-go/v2/api/usage/v1;usage'
  _STOREUSAGEEVENTREQUEST.fields_by_name['billing_id']._options = None
  _STOREUSAGEEVENTREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001'
  _GETSTREAMEVENTUSAGEREQUEST._serialized_start=182
  _GETSTREAMEVENTUSAGEREQUEST._serialized_end=402
  _GETSTREAMEVENTUSAGERESPONSE._serialized_start=405
  _GETSTREAMEVENTUSAGERESPONSE._serialized_end=553
  _STOREUSAGEEVENTREQUEST._serialized_start=556
  _STOREUSAGEEVENTREQUEST._serialized_end=717
  _STOREUSAGEEVENTRESPONSE._serialized_start=719
  _STOREUSAGEEVENTRESPONSE._serialized_end=744
  _USAGESERVICE._serialized_start=747
  _USAGESERVICE._serialized_end=1014
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/credentials/v1/credentials_v1.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from strmprivacy.api.entities.v1 import entities_v1_pb2 as strmprivacy_dot_api_dot_entities_dot_v1_dot_entities__v1__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3strmprivacy/api/credentials/v1/credentials_v1.proto\x12\x1estrmprivacy.api.credentials.v1\x1a\x1fgoogle/api/field_behavior.proto\x1a-strmprivacy/api/entities/v1/entities_v1.proto\"Y\n\x16ListCredentialsRequest\x12?\n\nstream_ref\x18\x01 \x01(\x0b\x32&.strmprivacy.api.entities.v1.StreamRefB\x03\xe0\x41\x02\"X\n\x17ListCredentialsResponse\x12=\n\x0b\x63redentials\x18\x01 \x03(\x0b\x32(.strmprivacy.api.entities.v1.Credentials\",\n\x17\x44\x65leteCredentialRequest\x12\x11\n\tclient_id\x18\x01 \x01(\t\"\x1a\n\x18\x44\x65leteCredentialResponse\")\n\x14GetCredentialRequest\x12\x11\n\tclient_id\x18\x01 \x01(\t\"U\n\x15GetCredentialResponse\x12<\n\ncredential\x18\x01 \x01(\x0b\x32(.strmprivacy.api.entities.v1.Credentials\"U\n\x17\x43reateCredentialRequest\x12:\n\nstream_ref\x18\x01 \x01(\x0b\x32&.strmprivacy.api.entities.v1.StreamRef\"Y\n\x18\x43reateCredentialResponse\x12=\n\x0b\x63redentials\x18\x01 \x01(\x0b\x32(.strmprivacy.api.entities.v1.Credentials2\xa7\x04\n\x12\x43redentialsService\x12\x82\x01\n\x0fListCredentials\x12\x36.strmprivacy.api.credentials.v1.ListCredentialsRequest\x1a\x37.strmprivacy.api.credentials.v1.ListCredentialsResponse\x12|\n\rGetCredential\x12\x34.strmprivacy.api.credentials.v1.GetCredentialRequest\x1a\x35.strmprivacy.api.credentials.v1.GetCredentialResponse\x12\x85\x01\n\x10\x43reateCredential\x12\x37.strmprivacy.api.credentials.v1.CreateCredentialRequest\x1a\x38.strmprivacy.api.credentials.v1.CreateCredentialResponse\x12\x85\x01\n\x10\x44\x65leteCredential\x12\x37.strmprivacy.api.credentials.v1.DeleteCredentialRequest\x1a\x38.strmprivacy.api.credentials.v1.DeleteCredentialResponseBr\n!io.strmprivacy.api.credentials.v1P\x01ZKgithub.com/strmprivacy/api-definitions-go/v2/api/credentials/v1;credentialsb\x06proto3')



_LISTCREDENTIALSREQUEST = DESCRIPTOR.message_types_by_name['ListCredentialsRequest']
_LISTCREDENTIALSRESPONSE = DESCRIPTOR.message_types_by_name['ListCredentialsResponse']
_DELETECREDENTIALREQUEST = DESCRIPTOR.message_types_by_name['DeleteCredentialRequest']
_DELETECREDENTIALRESPONSE = DESCRIPTOR.message_types_by_name['DeleteCredentialResponse']
_GETCREDENTIALREQUEST = DESCRIPTOR.message_types_by_name['GetCredentialRequest']
_GETCREDENTIALRESPONSE = DESCRIPTOR.message_types_by_name['GetCredentialResponse']
_CREATECREDENTIALREQUEST = DESCRIPTOR.message_types_by_name['CreateCredentialRequest']
_CREATECREDENTIALRESPONSE = DESCRIPTOR.message_types_by_name['CreateCredentialResponse']
ListCredentialsRequest = _reflection.GeneratedProtocolMessageType('ListCredentialsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTCREDENTIALSREQUEST,
  '__module__' : 'strmprivacy.api.credentials.v1.credentials_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.credentials.v1.ListCredentialsRequest)
  })
_sym_db.RegisterMessage(ListCredentialsRequest)

ListCredentialsResponse = _reflection.GeneratedProtocolMessageType('ListCredentialsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTCREDENTIALSRESPONSE,
  '__module__' : 'strmprivacy.api.credentials.v1.credentials_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.credentials.v1.ListCredentialsResponse)
  })
_sym_db.RegisterMessage(ListCredentialsResponse)

DeleteCredentialRequest = _reflection.GeneratedProtocolMessageType('DeleteCredentialRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETECREDENTIALREQUEST,
  '__module__' : 'strmprivacy.api.credentials.v1.credentials_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.credentials.v1.DeleteCredentialRequest)
  })
_sym_db.RegisterMessage(DeleteCredentialRequest)

DeleteCredentialResponse = _reflection.GeneratedProtocolMessageType('DeleteCredentialResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETECREDENTIALRESPONSE,
  '__module__' : 'strmprivacy.api.credentials.v1.credentials_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.credentials.v1.DeleteCredentialResponse)
  })
_sym_db.RegisterMessage(DeleteCredentialResponse)

GetCredentialRequest = _reflection.GeneratedProtocolMessageType('GetCredentialRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCREDENTIALREQUEST,
  '__module__' : 'strmprivacy.api.credentials.v1.credentials_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.credentials.v1.GetCredentialRequest)
  })
_sym_db.RegisterMessage(GetCredentialRequest)

GetCredentialResponse = _reflection.GeneratedProtocolMessageType('GetCredentialResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETCREDENTIALRESPONSE,
  '__module__' : 'strmprivacy.api.credentials.v1.credentials_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.credentials.v1.GetCredentialResponse)
  })
_sym_db.RegisterMessage(GetCredentialResponse)

CreateCredentialRequest = _reflection.GeneratedProtocolMessageType('CreateCredentialRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATECREDENTIALREQUEST,
  '__module__' : 'strmprivacy.api.credentials.v1.credentials_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.credentials.v1.CreateCredentialRequest)
  })
_sym_db.RegisterMessage(CreateCredentialRequest)

CreateCredentialResponse = _reflection.GeneratedProtocolMessageType('CreateCredentialResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATECREDENTIALRESPONSE,
  '__module__' : 'strmprivacy.api.credentials.v1.credentials_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.credentials.v1.CreateCredentialResponse)
  })
_sym_db.RegisterMessage(CreateCredentialResponse)

_CREDENTIALSSERVICE = DESCRIPTOR.services_by_name['CredentialsService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n!io.strmprivacy.api.credentials.v1P\001ZKgithub.com/strmprivacy/api-definitions-go/v2/api/credentials/v1;credentials'
  _LISTCREDENTIALSREQUEST.fields_by_name['stream_ref']._options = None
  _LISTCREDENTIALSREQUEST.fields_by_name['stream_ref']._serialized_options = b'\340A\002'
  _LISTCREDENTIALSREQUEST._serialized_start=167
  _LISTCREDENTIALSREQUEST._serialized_end=256
  _LISTCREDENTIALSRESPONSE._serialized_start=258
  _LISTCREDENTIALSRESPONSE._serialized_end=346
  _DELETECREDENTIALREQUEST._serialized_start=348
  _DELETECREDENTIALREQUEST._serialized_end=392
  _DELETECREDENTIALRESPONSE._serialized_start=394
  _DELETECREDENTIALRESPONSE._serialized_end=420
  _GETCREDENTIALREQUEST._serialized_start=422
  _GETCREDENTIALREQUEST._serialized_end=463
  _GETCREDENTIALRESPONSE._serialized_start=465
  _GETCREDENTIALRESPONSE._serialized_end=550
  _CREATECREDENTIALREQUEST._serialized_start=552
  _CREATECREDENTIALREQUEST._serialized_end=637
  _CREATECREDENTIALRESPONSE._serialized_start=639
  _CREATECREDENTIALRESPONSE._serialized_end=728
  _CREDENTIALSSERVICE._serialized_start=731
  _CREDENTIALSSERVICE._serialized_end=1282
# @@protoc_insertion_point(module_scope)
